==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyProviderFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthorizationPolicyProviderFluent<A extends AuthorizationPolicyProviderFluent<A>> extends BaseFluent<A>{
  public AuthorizationPolicyProviderFluent() {
  }
  public AuthorizationPolicyProviderFluent(AuthorizationPolicyProvider instance) {
    instance = (instance != null ? instance : new AuthorizationPolicyProvider());

    if (instance != null) {
      this.withProvider(instance.getProvider());
      this.withProvider(instance.getProvider());
    }
  }
  private AuthorizationPolicyExtensionProviderBuilder provider;
  public AuthorizationPolicyExtensionProvider buildProvider() {
    return this.provider!=null ?this.provider.build():null;
  }
  public A withProvider(AuthorizationPolicyExtensionProvider provider) {
    _visitables.get("provider").remove(this.provider);
    if (provider!=null){ this.provider= new AuthorizationPolicyExtensionProviderBuilder(provider); _visitables.get("provider").add(this.provider);} else { this.provider = null; _visitables.get("provider").remove(this.provider); } return (A) this;
  }
  public boolean hasProvider() {
    return this.provider != null;
  }
  public A withNewProvider(String name) {
    return (A)withProvider(new AuthorizationPolicyExtensionProvider(name));
  }
  public ProviderNested<A> withNewProvider() {
    return new ProviderNested(null);
  }
  public ProviderNested<A> withNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return new ProviderNested(item);
  }
  public ProviderNested<A> editProvider() {
    return withNewProviderLike(java.util.Optional.ofNullable(buildProvider()).orElse(null));
  }
  public ProviderNested<A> editOrNewProvider() {
    return withNewProviderLike(java.util.Optional.ofNullable(buildProvider()).orElse(new AuthorizationPolicyExtensionProviderBuilder().build()));
  }
  public ProviderNested<A> editOrNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return withNewProviderLike(java.util.Optional.ofNullable(buildProvider()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthorizationPolicyProviderFluent that = (AuthorizationPolicyProviderFluent) o;
    if (!java.util.Objects.equals(provider, that.provider)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(provider,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (provider != null) { sb.append("provider:"); sb.append(provider); }
    sb.append("}");
    return sb.toString();
  }
  public class ProviderNested<N> extends AuthorizationPolicyExtensionProviderFluent<ProviderNested<N>> implements Nested<N>{
    ProviderNested(AuthorizationPolicyExtensionProvider item) {
      this.builder = new AuthorizationPolicyExtensionProviderBuilder(this, item);
    }
    AuthorizationPolicyExtensionProviderBuilder builder;
    public N and() {
      return (N) AuthorizationPolicyProviderFluent.this.withProvider(builder.build());
    }
    public N endProvider() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyProviderFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AuthorizationPolicyProviderFluent<A extends AuthorizationPolicyProviderFluent<A>> extends BaseFluent<A>{
  public AuthorizationPolicyProviderFluent() {
  }
  
  public AuthorizationPolicyProviderFluent(AuthorizationPolicyProvider instance) {
    this.copyInstance(instance);
  }
  private AuthorizationPolicyExtensionProviderBuilder provider;
  
  protected void copyInstance(AuthorizationPolicyProvider instance) {
    instance = (instance != null ? instance : new AuthorizationPolicyProvider());
  
    if (instance != null) {
        this.withProvider(instance.getProvider());
        this.withProvider(instance.getProvider());
      }
  }
  
  public AuthorizationPolicyExtensionProvider buildProvider() {
    return this.provider!=null ?this.provider.build():null;
  }
  
  public A withProvider(AuthorizationPolicyExtensionProvider provider) {
    _visitables.get("provider").remove(this.provider);
    if (provider!=null){ this.provider= new AuthorizationPolicyExtensionProviderBuilder(provider); _visitables.get("provider").add(this.provider);} else { this.provider = null; _visitables.get("provider").remove(this.provider); } return (A) this;
  }
  
  public boolean hasProvider() {
    return this.provider != null;
  }
  
  public A withNewProvider(String name) {
    return (A)withProvider(new AuthorizationPolicyExtensionProvider(name));
  }
  
  public ProviderNested<A> withNewProvider() {
    return new ProviderNested(null);
  }
  
  public ProviderNested<A> withNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return new ProviderNested(item);
  }
  
  public ProviderNested<A> editProvider() {
    return withNewProviderLike(java.util.Optional.ofNullable(buildProvider()).orElse(null));
  }
  
  public ProviderNested<A> editOrNewProvider() {
    return withNewProviderLike(java.util.Optional.ofNullable(buildProvider()).orElse(new AuthorizationPolicyExtensionProviderBuilder().build()));
  }
  
  public ProviderNested<A> editOrNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return withNewProviderLike(java.util.Optional.ofNullable(buildProvider()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthorizationPolicyProviderFluent that = (AuthorizationPolicyProviderFluent) o;
    if (!java.util.Objects.equals(provider, that.provider)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(provider,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (provider != null) { sb.append("provider:"); sb.append(provider); }
    sb.append("}");
    return sb.toString();
  }
  public class ProviderNested<N> extends AuthorizationPolicyExtensionProviderFluent<ProviderNested<N>> implements Nested<N>{
    ProviderNested(AuthorizationPolicyExtensionProvider item) {
      this.builder = new AuthorizationPolicyExtensionProviderBuilder(this, item);
    }
    AuthorizationPolicyExtensionProviderBuilder builder;
    
    public N and() {
      return (N) AuthorizationPolicyProviderFluent.this.withProvider(builder.build());
    }
    
    public N endProvider() {
      return and();
    }
    
  
  }

}
